pub struct EnvWithHandlerCfg {
pub env: Box<Env>,
pub handler_cfg: HandlerCfg,
}Expand description
Evm environment with the chain spec id.
Fields
env: Box<Env>Evm enironment.
handler_cfg: HandlerCfgHandler configuration fields.
Implementations
Sourceimpl EnvWithHandlerCfg
impl EnvWithHandlerCfg
Sourcepub fn new(env: Box<Env>, handler_cfg: HandlerCfg) -> Self
pub fn new(env: Box<Env>, handler_cfg: HandlerCfg) -> Self
Returns new EnvWithHandlerCfg instance.
Sourcepub fn new_with_spec_id(env: Box<Env>, spec_id: SpecId) -> Self
pub fn new_with_spec_id(env: Box<Env>, spec_id: SpecId) -> Self
Returns new EnvWithHandlerCfg instance with the chain spec id.
is_optimism will be set to default value depending on optimism-default-handler feature.
Sourcepub fn new_with_cfg_env(
cfg: CfgEnvWithHandlerCfg,
block: BlockEnv,
tx: TxEnv,
) -> Self
pub fn new_with_cfg_env( cfg: CfgEnvWithHandlerCfg, block: BlockEnv, tx: TxEnv, ) -> Self
Takes CfgEnvWithHandlerCfg and returns new EnvWithHandlerCfg instance.
Sourcepub fn enable_optimism(&mut self)
pub fn enable_optimism(&mut self)
Enables the optimism handle register.
Methods from Deref<Target = Env>
Sourcepub fn effective_gas_price(&self) -> U256
pub fn effective_gas_price(&self) -> U256
Calculates the effective gas price of the transaction.
Sourcepub fn calc_data_fee(&self) -> Option<U256>
pub fn calc_data_fee(&self) -> Option<U256>
Calculates the EIP-4844 data_fee of the transaction.
Returns None if Cancun is not enabled. This is enforced in Env::validate_block_env.
Sourcepub fn calc_max_data_fee(&self) -> Option<U256>
pub fn calc_max_data_fee(&self) -> Option<U256>
Calculates the maximum [EIP-4844] data_fee of the transaction.
This is used for ensuring that the user has at least enough funds to pay the
max_fee_per_blob_gas * total_blob_gas, on top of regular gas costs.
See EIP-4844: https://github.com/ethereum/EIPs/blob/master/EIPS/eip-4844.md#execution-layer-validation
Sourcepub fn validate_block_env<SPEC: Spec>(&self) -> Result<(), InvalidHeader>
pub fn validate_block_env<SPEC: Spec>(&self) -> Result<(), InvalidHeader>
Validate the block environment.
Sourcepub fn validate_tx<SPEC: Spec>(&self) -> Result<(), InvalidTransaction>
pub fn validate_tx<SPEC: Spec>(&self) -> Result<(), InvalidTransaction>
Validate transaction data that is set inside ENV and return error if something is wrong.
Return initial spend gas (Gas needed to execute transaction).
Sourcepub fn validate_tx_against_state<SPEC: Spec>(
&self,
account: &mut Account,
) -> Result<(), InvalidTransaction>
pub fn validate_tx_against_state<SPEC: Spec>( &self, account: &mut Account, ) -> Result<(), InvalidTransaction>
Validate transaction against state.